==> Net-SecurityCenter-0.200.tar.gz: Net-SecurityCenter-0.200/INSTALL.md <==
# Net::SecurityCenter - Perl interface to Tenable.sc (SecurityCenter) REST API

The INSTALL is used to introduce the module and provide instructions on
how to install the module, any machine dependencies it may have (for
example C compilers and installed libraries) and any other information
that should be provided before the module is installed.

## INSTALLATION

To install this module, run the following commands:

    perl Makefile.PL
    make
    make test
    make install

## SUPPORT AND DOCUMENTATION

After installing, you can find documentation for this module with the
perldoc command.

    perldoc Net::SecurityCenter
    perldoc Net::SecurityCenter::REST
    perldoc Net::SecurityCenter::API
    perldoc Net::SecurityCenter::API::Analysis
    perldoc Net::SecurityCenter::API::Credential
    perldoc Net::SecurityCenter::API::Feed
    perldoc Net::SecurityCenter::API::File
    perldoc Net::SecurityCenter::API::Plugin
    perldoc Net::SecurityCenter::API::PluginFamily
    perldoc Net::SecurityCenter::API::Policy
    perldoc Net::SecurityCenter::API::Report
    perldoc Net::SecurityCenter::API::Repository
    perldoc Net::SecurityCenter::API::Scan
    perldoc Net::SecurityCenter::API::ScanResult
    perldoc Net::SecurityCenter::API::Scanner
    perldoc Net::SecurityCenter::API::System
    perldoc Net::SecurityCenter::API::User
    perldoc Net::SecurityCenter::API::Zone
    perldoc Net::SecurityCenter::Utils

You can also look for information at:

  * GitHub issues (report bugs here) https://github.com/LotarProject/perl-Net-SecurityCenter/issues
  * SlackMan documentation https://github.com/LotarProject/perl-Net-SecurityCenter/wiki


## LICENSE AND COPYRIGHT

Copyright (C) 2018-2019 Giuseppe Di Terlizzi

This program is free software; you can redistribute it and/or modify it
under the terms of the the Artistic License (2.0). You may obtain a
copy of the full license at:

http://www.perlfoundation.org/artistic_license_2_0

Any use, modification, and distribution of the Standard or Modified
Versions is governed by this Artistic License. By using, modifying or
distributing the Package, you accept this license. Do not use, modify,
or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made
by someone other than you, you are nevertheless required to ensure that
your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service
mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge
patent license to make, have made, use, offer to sell, sell, import and
otherwise transfer the Package with respect to any patent claims
licensable by the Copyright Holder that are necessarily infringed by the
Package. If you institute patent litigation (including a cross-claim or
counterclaim) against any party alleging that the Package constitutes
direct or contributory patent infringement, then this Artistic License
to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

==> Net-SecurityCenter-0.205.tar.gz: Net-SecurityCenter-0.205/INSTALL.md <==
# Net::SecurityCenter - Perl interface to Tenable.sc (SecurityCenter) REST API

The INSTALL is used to introduce the module and provide instructions on
how to install the module, any machine dependencies it may have (for
example C compilers and installed libraries) and any other information
that should be provided before the module is installed.

## INSTALLATION

To install this module, run the following commands:

    perl Makefile.PL
    make
    make test
    make install

## SUPPORT AND DOCUMENTATION

After installing, you can find documentation for this module with the
perldoc command.

    perldoc Net::SecurityCenter
    perldoc Net::SecurityCenter::REST
    perldoc Net::SecurityCenter::API
    perldoc Net::SecurityCenter::API::Analysis
    perldoc Net::SecurityCenter::API::Credential
    perldoc Net::SecurityCenter::API::Feed
    perldoc Net::SecurityCenter::API::File
    perldoc Net::SecurityCenter::API::Plugin
    perldoc Net::SecurityCenter::API::PluginFamily
    perldoc Net::SecurityCenter::API::Policy
    perldoc Net::SecurityCenter::API::Report
    perldoc Net::SecurityCenter::API::Repository
    perldoc Net::SecurityCenter::API::Scan
    perldoc Net::SecurityCenter::API::ScanResult
    perldoc Net::SecurityCenter::API::Scanner
    perldoc Net::SecurityCenter::API::System
    perldoc Net::SecurityCenter::API::User
    perldoc Net::SecurityCenter::API::Zone
    perldoc Net::SecurityCenter::Utils

You can also look for information at:

  * GitHub issues (report bugs here) https://github.com/giterlizzi/perl-Net-SecurityCenter/issues
  * SlackMan documentation https://github.com/giterlizzi/perl-Net-SecurityCenter/wiki


## LICENSE AND COPYRIGHT

Copyright (C) 2018-2019 Giuseppe Di Terlizzi

This program is free software; you can redistribute it and/or modify it
under the terms of the the Artistic License (2.0). You may obtain a
copy of the full license at:

http://www.perlfoundation.org/artistic_license_2_0

Any use, modification, and distribution of the Standard or Modified
Versions is governed by this Artistic License. By using, modifying or
distributing the Package, you accept this license. Do not use, modify,
or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made
by someone other than you, you are nevertheless required to ensure that
your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service
mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge
patent license to make, have made, use, offer to sell, sell, import and
otherwise transfer the Package with respect to any patent claims
licensable by the Copyright Holder that are necessarily infringed by the
Package. If you institute patent litigation (including a cross-claim or
counterclaim) against any party alleging that the Package constitutes
direct or contributory patent infringement, then this Artistic License
to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
